==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/he.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "אחסון לא זמין",
    "Storage invalid" : "אחסון לא חוקי",
    "Unknown error" : "שגיאה בלתי ידועה",
    "Unable to set upload directory." : "לא היה ניתן לקבוע תיקיית העלאות.",
    "Invalid Token" : "קוד לא חוקי",
    "No file was uploaded. Unknown error" : "לא הועלה קובץ. טעות בלתי מזוהה.",
    "There is no error, the file uploaded with success" : "לא התרחשה שגיאה, הקובץ הועלה בהצלחה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "הקבצים שנשלחו חורגים מהגודל שצוין בהגדרה upload_max_filesize שבקובץ php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה גדוך מהערך MAX_FILE_SIZE שהוגדר בתופס HTML",
    "The uploaded file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "שום קובץ לא הועלה",
    "Missing a temporary folder" : "תקיה זמנית חסרה",
    "Failed to write to disk" : "הכתיבה לכונן נכשלה",
    "Not enough storage available" : "אין די שטח פנוי באחסון",
    "The target folder has been moved or deleted." : "תיקיית המטרה הועברה או נמחקה.",
    "Upload failed. Could not find uploaded file" : "העלאה נכשלה. לא נמצא הקובץ להעלאה",
    "Upload failed. Could not get file info." : "העלאה נכשלה. לא ניתן להשיג את פרטי הקובץ.",
    "Invalid directory." : "תיקייה שגויה.",
    "Files" : "קבצים",
    "All files" : "כל הקבצים",
    "Favorites" : "מועדפים",
    "Home" : "בית",
    "Close" : "סגירה",
    "Upload cancelled." : "ההעלאה בוטלה.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "לא ניתן להעלות {filename} כיוון שמדובר בתיקייה או שגודלו 0 בייט",
    "Total file size {size1} exceeds upload limit {size2}" : "גודל הקובת {size1} עובר את מגבלת הגודל להעלאה {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "לא קיים מספיק מקום פנוי, הקובץ המיועד להעלאה {size1} אבל נשאר {size2} בלבד",
    "Error uploading file \"{fileName}\": {message}" : "שגיאה בזמן העלאת קובץ \"{fileName}\": {message}",
    "Could not get result from server." : "לא ניתן לגשת לתוצאות מהשרת.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "מתבצעת כעת העלאת קבצים. עזיבה של העמוד תבטל את ההעלאה.",
    "Actions" : "פעולות",
    "Download" : "הורדה",
    "Rename" : "שינוי שם",
    "Delete" : "מחיקה",
    "Disconnect storage" : "ניתוק אחסון",
    "Unshare" : "הסר שיתוף",
    "Details" : "פרטים",
    "Select" : "בחר",
    "Pending" : "ממתין",
    "Unable to determine date" : "לא ניתן לקבוע תאריך",
    "This operation is forbidden" : "פעולה זו אסורה",
    "This directory is unavailable, please check the logs or contact the administrator" : "תיקייה זו לא קיימת, יש לבדוק את הלוגים או ליצור קשר עם המנהל",
    "Could not move \"{file}\", target exists" : "לא ניתן להעביר \"{file}\", קובץ מטרה קיים",
    "Could not move \"{file}\"" : "לא ניתן להעביר \"{file}\"",
    "{newName} already exists" : "{newName} כבר קיים",
    "Could not rename \"{fileName}\", it does not exist any more" : "לא ניתן לשנות שם \"{fileName}\", הוא כבר לא קיים יותר",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "השם \"{targetName}\" כבר קיים בתיקייה \"{dir}\". יש לבחור שם אחר.",
    "Could not rename \"{fileName}\"" : "לא ניתן לשנות את השם \"{fileName}\"",
    "Could not create file \"{file}\"" : "לא ניתן ליצור את הקובץ \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "לא ניתן ליצור את הקובץ \"{file}\" כיוון שהוא כבר קיים",
    "Could not create folder \"{dir}\"" : "לא ניתן ליצור את התיקייה \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "לא ניתן ליצור את התיקייה \"{dir}\" כיוון שהיא כבר קיימת",
    "Error deleting file \"{fileName}\"." : "שגיאה בזמן מחיקת קובץ \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "לא נמצאו התאמות בתיקייה זו ל- '{filter}'",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "זמן שינוי",
    "_%n folder_::_%n folders_" : ["%n תיקייה","%n תיקיות"],
    "_%n file_::_%n files_" : ["%n קובץ","%n קבצים"],
    "{dirs} and {files}" : "{dirs} וכן {files}",
    "You don’t have permission to upload or create files here" : "אין לך הרשאות להעלות או ליצור קבצים כאן",
    "_Uploading %n file_::_Uploading %n files_" : ["מעלה %n קובץ","מעלה %n קבצים"],
    "New" : "חדש",
    "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "האחסון של {owner} מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Your storage is full, files can not be updated or synced anymore!" : "האחסון שלך מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "האחסון של {owner} כמעט מלא ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "שטח האחסון שלך כמעט מלא ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["מתאים ל- '{filter}'","מתאים ל- '{filter}'"],
    "Path" : "נתיב",
    "_%n byte_::_%n bytes_" : ["%n בייט","%n בייטים"],
    "Favorited" : "מועדף",
    "Favorite" : "מועדף",
    "Folder" : "תיקייה",
    "New folder" : "תיקייה חדשה",
    "{newname} already exists" : "{newname} כבר קיים",
    "Upload" : "העלאה",
    "An error occurred while trying to update the tags" : "שגיאה אירעה בזמן עדכון התגיות",
    "A new file or folder has been <strong>created</strong>" : "קובץ או תיקייה חדשים <strong>נוצרו<strong/>",
    "A file or folder has been <strong>changed</strong>" : "קובץ או תיקייה <strong>שונו<strong/>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "הגבלת הודעות על יצירת או שינוי <strong>הקבצים המועדפים</strong> שלך <em>(Stream only)</em>",
    "A file or folder has been <strong>deleted</strong>" : "קובץ או תיקייה <strong>נמחקו<strong/>",
    "A file or folder has been <strong>restored</strong>" : "קובץ או תיקייה <strong>שוחזר</strong>",
    "You created %1$s" : "יצרת %1$s",
    "%2$s created %1$s" : "%2$s נוצרו %1$s",
    "%1$s was created in a public folder" : "%1$s נוצר בתיקייה ציבורית",
    "You changed %1$s" : "שינית %1$s",
    "%2$s changed %1$s" : "%2$s שונו %1$s",
    "You deleted %1$s" : "מחקת %1$s",
    "%2$s deleted %1$s" : "%2$s נמחקו %1$s",
    "You restored %1$s" : "שחזרת %1$s",
    "%2$s restored %1$s" : "%2$s שוחזרו %1$s",
    "Changed by %2$s" : "שונו על ידי %2$s",
    "Deleted by %2$s" : "נמחקו על ידי %2$s",
    "Restored by %2$s" : "שוחזרו על ידי %2$s",
    "Upload (max. %s)" : "העלאה (מקסימום %s)",
    "File handling" : "טיפול בקבצים",
    "Maximum upload size" : "גודל העלאה מקסימלי",
    "max. possible: " : "המרבי האפשרי: ",
    "Save" : "שמירה",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "בשימוש ב- PHP-FPM זה יכול להמשך 5 דקות לשינויים לחול.",
    "Missing permissions to edit from here." : "חסרות הרשאות לעריכה מכאן.",
    "Settings" : "הגדרות",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "השתמש בכתובת זו לצורך <a href=\"%s\" target=\"_blank\">כניסה אל הקבצים שלך בעזרת WebDAV</a>",
    "Cancel upload" : "ביטול ההעלאה",
    "No files in here" : "אין כאן קבצים",
    "Upload some content or sync with your devices!" : "יש להעלות קצת תוכן או לסנכרן עם ההתקנים שלך!",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Select all" : "לבחור הכול",
    "Upload too large" : "העלאה גדולה מידי",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "הקבצים שניסית להעלות חרגו מהגודל המקסימלי להעלאת קבצים על שרת זה.",
    "No favorites" : "אין מועדפים",
    "Files and folders you mark as favorite will show up here" : "קבצים ותיקיות שסומנו על ידך כמועדפים יוצגו כאן",
    "Text file" : "קובץ טקסט",
    "New text file.txt" : "קובץ טקסט חדש.txt"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/he.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "אחסון לא זמין",
    "Storage invalid" : "אחסון לא חוקי",
    "Unknown error" : "שגיאה בלתי ידועה",
    "Unable to set upload directory." : "לא היה ניתן לקבוע תיקיית העלאות.",
    "Invalid Token" : "קוד לא חוקי",
    "No file was uploaded. Unknown error" : "לא הועלה קובץ. טעות בלתי מזוהה.",
    "There is no error, the file uploaded with success" : "לא התרחשה שגיאה, הקובץ הועלה בהצלחה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "הקבצים שנשלחו חורגים מהגודל שצוין בהגדרה upload_max_filesize שבקובץ php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה גדוך מהערך MAX_FILE_SIZE שהוגדר בתופס HTML",
    "The uploaded file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "No file was uploaded" : "שום קובץ לא הועלה",
    "Missing a temporary folder" : "תקיה זמנית חסרה",
    "Failed to write to disk" : "הכתיבה לכונן נכשלה",
    "Not enough storage available" : "אין די שטח פנוי באחסון",
    "The target folder has been moved or deleted." : "תיקיית המטרה הועברה או נמחקה.",
    "Upload failed. Could not find uploaded file" : "העלאה נכשלה. לא נמצא הקובץ להעלאה",
    "Upload failed. Could not get file info." : "העלאה נכשלה. לא ניתן להשיג את פרטי הקובץ.",
    "Invalid directory." : "תיקייה שגויה.",
    "Files" : "קבצים",
    "All files" : "כל הקבצים",
    "Favorites" : "מועדפים",
    "Home" : "בית",
    "Close" : "סגירה",
    "Upload cancelled." : "ההעלאה בוטלה.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "לא ניתן להעלות {filename} כיוון שמדובר בתיקייה או שגודלו 0 בייט",
    "Total file size {size1} exceeds upload limit {size2}" : "גודל הקובת {size1} עובר את מגבלת הגודל להעלאה {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "לא קיים מספיק מקום פנוי, הקובץ המיועד להעלאה {size1} אבל נשאר {size2} בלבד",
    "Error uploading file \"{fileName}\": {message}" : "שגיאה בזמן העלאת קובץ \"{fileName}\": {message}",
    "Could not get result from server." : "לא ניתן לגשת לתוצאות מהשרת.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "מתבצעת כעת העלאת קבצים. עזיבה של העמוד תבטל את ההעלאה.",
    "Actions" : "פעולות",
    "Download" : "הורדה",
    "Rename" : "שינוי שם",
    "Delete" : "מחיקה",
    "Disconnect storage" : "ניתוק אחסון",
    "Unshare" : "הסר שיתוף",
    "Details" : "פרטים",
    "Select" : "בחר",
    "Pending" : "ממתין",
    "Unable to determine date" : "לא ניתן לקבוע תאריך",
    "This operation is forbidden" : "פעולה זו אסורה",
    "This directory is unavailable, please check the logs or contact the administrator" : "תיקייה זו לא קיימת, יש לבדוק את הלוגים או ליצור קשר עם המנהל",
    "Could not move \"{file}\", target exists" : "לא ניתן להעביר \"{file}\", קובץ מטרה קיים",
    "Could not move \"{file}\"" : "לא ניתן להעביר \"{file}\"",
    "{newName} already exists" : "{newName} כבר קיים",
    "Could not rename \"{fileName}\", it does not exist any more" : "לא ניתן לשנות שם \"{fileName}\", הוא כבר לא קיים יותר",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "השם \"{targetName}\" כבר קיים בתיקייה \"{dir}\". יש לבחור שם אחר.",
    "Could not rename \"{fileName}\"" : "לא ניתן לשנות את השם \"{fileName}\"",
    "Could not create file \"{file}\"" : "לא ניתן ליצור את הקובץ \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "לא ניתן ליצור את הקובץ \"{file}\" כיוון שהוא כבר קיים",
    "Could not create folder \"{dir}\"" : "לא ניתן ליצור את התיקייה \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "לא ניתן ליצור את התיקייה \"{dir}\" כיוון שהיא כבר קיימת",
    "Error deleting file \"{fileName}\"." : "שגיאה בזמן מחיקת קובץ \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "לא נמצאו התאמות בתיקייה זו ל- '{filter}'",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "זמן שינוי",
    "_%n folder_::_%n folders_" : ["%n תיקייה","%n תיקיות"],
    "_%n file_::_%n files_" : ["%n קובץ","%n קבצים"],
    "{dirs} and {files}" : "{dirs} וכן {files}",
    "You don’t have permission to upload or create files here" : "אין לך הרשאות להעלות או ליצור קבצים כאן",
    "_Uploading %n file_::_Uploading %n files_" : ["מעלה %n קובץ","מעלה %n קבצים"],
    "New" : "חדש",
    "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "האחסון של {owner} מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Your storage is full, files can not be updated or synced anymore!" : "האחסון שלך מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "האחסון של {owner} כמעט מלא ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "שטח האחסון שלך כמעט מלא ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["מתאים ל- '{filter}'","מתאים ל- '{filter}'"],
    "Path" : "נתיב",
    "_%n byte_::_%n bytes_" : ["%n בייט","%n בייטים"],
    "Favorited" : "מועדף",
    "Favorite" : "מועדף",
    "Folder" : "תיקייה",
    "New folder" : "תיקייה חדשה",
    "{newname} already exists" : "{newname} כבר קיים",
    "Upload" : "העלאה",
    "An error occurred while trying to update the tags" : "שגיאה אירעה בזמן עדכון התגיות",
    "A new file or folder has been <strong>created</strong>" : "קובץ או תיקייה חדשים <strong>נוצרו<strong/>",
    "A file or folder has been <strong>changed</strong>" : "קובץ או תיקייה <strong>שונו<strong/>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "הגבלת הודעות על יצירת או שינוי <strong>הקבצים המועדפים</strong> שלך <em>(Stream only)</em>",
    "A file or folder has been <strong>deleted</strong>" : "קובץ או תיקייה <strong>נמחקו<strong/>",
    "A file or folder has been <strong>restored</strong>" : "קובץ או תיקייה <strong>שוחזר</strong>",
    "You created %1$s" : "יצרת %1$s",
    "%2$s created %1$s" : "%2$s נוצרו %1$s",
    "%1$s was created in a public folder" : "%1$s נוצר בתיקייה ציבורית",
    "You changed %1$s" : "שינית %1$s",
    "%2$s changed %1$s" : "%2$s שונו %1$s",
    "You deleted %1$s" : "מחקת %1$s",
    "%2$s deleted %1$s" : "%2$s נמחקו %1$s",
    "You restored %1$s" : "שחזרת %1$s",
    "%2$s restored %1$s" : "%2$s שוחזרו %1$s",
    "Changed by %2$s" : "שונו על ידי %2$s",
    "Deleted by %2$s" : "נמחקו על ידי %2$s",
    "Restored by %2$s" : "שוחזרו על ידי %2$s",
    "Upload (max. %s)" : "העלאה (מקסימום %s)",
    "File handling" : "טיפול בקבצים",
    "Maximum upload size" : "גודל העלאה מקסימלי",
    "max. possible: " : "המרבי האפשרי: ",
    "Save" : "שמירה",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "בשימוש ב- PHP-FPM זה יכול להמשך 5 דקות לשינויים לחול.",
    "Missing permissions to edit from here." : "חסרות הרשאות לעריכה מכאן.",
    "Settings" : "הגדרות",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "השתמש בכתובת זו לצורך <a href=\"%s\" target=\"_blank\">כניסה אל הקבצים שלך בעזרת WebDAV</a>",
    "Cancel upload" : "ביטול ההעלאה",
    "No files in here" : "אין כאן קבצים",
    "Upload some content or sync with your devices!" : "יש להעלות קצת תוכן או לסנכרן עם ההתקנים שלך!",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Select all" : "לבחור הכול",
    "Upload too large" : "העלאה גדולה מידי",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "הקבצים שניסית להעלות חרגו מהגודל המקסימלי להעלאת קבצים על שרת זה.",
    "No favorites" : "אין מועדפים",
    "Files and folders you mark as favorite will show up here" : "קבצים ותיקיות שסומנו על ידך כמועדפים יוצגו כאן",
    "Text file" : "קובץ טקסט",
    "New text file.txt" : "קובץ טקסט חדש.txt",
    "Changed by %2$s" : "שונו על ידי %2$s",
    "Deleted by %2$s" : "נמחקו על ידי %2$s",
    "Restored by %2$s" : "שוחזרו על ידי %2$s",
    "You changed %1$s" : "שינית %1$s",
    "You created %1$s" : "יצרת %1$s",
    "You deleted %1$s" : "מחקת %1$s",
    "You restored %1$s" : "שחזרת %1$s"
},
"nplurals=2; plural=(n != 1);");
